from setuptools import setup

setup(
    name='orkas',
    version='0.0.1',
    description="DataFrame dialect",
    url='https://github.com/kszucs',
    author='kszucs',
    author_email='kszucs@kszucs.me',
    packages=[],
)
